'''_2253.py

InterMountableComponentConnectionSystemDeflection
'''


from mastapy.system_model.connections_and_sockets import (
    _1824, _1811, _1816, _1831
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.connections_and_sockets.gears import (
    _1839, _1841, _1843, _1845,
    _1847, _1849, _1851, _1853,
    _1855, _1858, _1859, _1860,
    _1863, _1865, _1867, _1869,
    _1871
)
from mastapy.system_model.connections_and_sockets.couplings import (
    _1873, _1875, _1877, _1879,
    _1881, _1883
)
from mastapy.system_model.analyses_and_results.power_flows import (
    _3254, _3196, _3201, _3203,
    _3208, _3213, _3218, _3221,
    _3224, _3229, _3232, _3236,
    _3242, _3246, _3250, _3255,
    _3258, _3261, _3269, _3281,
    _3288, _3291, _3294, _3297,
    _3307, _3313, _3316
)
from mastapy.system_model.analyses_and_results.system_deflections import _2220
from mastapy._internal.python_net import python_net_import

_INTER_MOUNTABLE_COMPONENT_CONNECTION_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'InterMountableComponentConnectionSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('InterMountableComponentConnectionSystemDeflection',)


class InterMountableComponentConnectionSystemDeflection(_2220.ConnectionSystemDeflection):
    '''InterMountableComponentConnectionSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _INTER_MOUNTABLE_COMPONENT_CONNECTION_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'InterMountableComponentConnectionSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def connection_design(self) -> '_1824.InterMountableComponentConnection':
        '''InterMountableComponentConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1824.InterMountableComponentConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_belt_connection(self) -> '_1811.BeltConnection':
        '''BeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1811.BeltConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BeltConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1811.BeltConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_cvt_belt_connection(self) -> '_1816.CVTBeltConnection':
        '''CVTBeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1816.CVTBeltConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to CVTBeltConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1816.CVTBeltConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_rolling_ring_connection(self) -> '_1831.RollingRingConnection':
        '''RollingRingConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1831.RollingRingConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to RollingRingConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1831.RollingRingConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_agma_gleason_conical_gear_mesh(self) -> '_1839.AGMAGleasonConicalGearMesh':
        '''AGMAGleasonConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1839.AGMAGleasonConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to AGMAGleasonConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1839.AGMAGleasonConicalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_bevel_differential_gear_mesh(self) -> '_1841.BevelDifferentialGearMesh':
        '''BevelDifferentialGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1841.BevelDifferentialGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BevelDifferentialGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1841.BevelDifferentialGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_bevel_gear_mesh(self) -> '_1843.BevelGearMesh':
        '''BevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1843.BevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1843.BevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_concept_gear_mesh(self) -> '_1845.ConceptGearMesh':
        '''ConceptGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1845.ConceptGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ConceptGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1845.ConceptGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_conical_gear_mesh(self) -> '_1847.ConicalGearMesh':
        '''ConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1847.ConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1847.ConicalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_cylindrical_gear_mesh(self) -> '_1849.CylindricalGearMesh':
        '''CylindricalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1849.CylindricalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to CylindricalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1849.CylindricalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_face_gear_mesh(self) -> '_1851.FaceGearMesh':
        '''FaceGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1851.FaceGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to FaceGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1851.FaceGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_gear_mesh(self) -> '_1853.GearMesh':
        '''GearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1853.GearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to GearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1853.GearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_hypoid_gear_mesh(self) -> '_1855.HypoidGearMesh':
        '''HypoidGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1855.HypoidGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to HypoidGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1855.HypoidGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_conical_gear_mesh(self) -> '_1858.KlingelnbergCycloPalloidConicalGearMesh':
        '''KlingelnbergCycloPalloidConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1858.KlingelnbergCycloPalloidConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1858.KlingelnbergCycloPalloidConicalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_hypoid_gear_mesh(self) -> '_1859.KlingelnbergCycloPalloidHypoidGearMesh':
        '''KlingelnbergCycloPalloidHypoidGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1859.KlingelnbergCycloPalloidHypoidGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidHypoidGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1859.KlingelnbergCycloPalloidHypoidGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh(self) -> '_1860.KlingelnbergCycloPalloidSpiralBevelGearMesh':
        '''KlingelnbergCycloPalloidSpiralBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1860.KlingelnbergCycloPalloidSpiralBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidSpiralBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1860.KlingelnbergCycloPalloidSpiralBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_spiral_bevel_gear_mesh(self) -> '_1863.SpiralBevelGearMesh':
        '''SpiralBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1863.SpiralBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to SpiralBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1863.SpiralBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_straight_bevel_diff_gear_mesh(self) -> '_1865.StraightBevelDiffGearMesh':
        '''StraightBevelDiffGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1865.StraightBevelDiffGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to StraightBevelDiffGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1865.StraightBevelDiffGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_straight_bevel_gear_mesh(self) -> '_1867.StraightBevelGearMesh':
        '''StraightBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1867.StraightBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to StraightBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1867.StraightBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_worm_gear_mesh(self) -> '_1869.WormGearMesh':
        '''WormGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1869.WormGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to WormGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1869.WormGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_zerol_bevel_gear_mesh(self) -> '_1871.ZerolBevelGearMesh':
        '''ZerolBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1871.ZerolBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ZerolBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1871.ZerolBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_clutch_connection(self) -> '_1873.ClutchConnection':
        '''ClutchConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1873.ClutchConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ClutchConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1873.ClutchConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_concept_coupling_connection(self) -> '_1875.ConceptCouplingConnection':
        '''ConceptCouplingConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1875.ConceptCouplingConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ConceptCouplingConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1875.ConceptCouplingConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_coupling_connection(self) -> '_1877.CouplingConnection':
        '''CouplingConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1877.CouplingConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to CouplingConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1877.CouplingConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_part_to_part_shear_coupling_connection(self) -> '_1879.PartToPartShearCouplingConnection':
        '''PartToPartShearCouplingConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1879.PartToPartShearCouplingConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to PartToPartShearCouplingConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1879.PartToPartShearCouplingConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_spring_damper_connection(self) -> '_1881.SpringDamperConnection':
        '''SpringDamperConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1881.SpringDamperConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to SpringDamperConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1881.SpringDamperConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_torque_converter_connection(self) -> '_1883.TorqueConverterConnection':
        '''TorqueConverterConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1883.TorqueConverterConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to TorqueConverterConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1883.TorqueConverterConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def power_flow_results(self) -> '_3254.InterMountableComponentConnectionPowerFlow':
        '''InterMountableComponentConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_3254.InterMountableComponentConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_agma_gleason_conical_gear_mesh_power_flow(self) -> '_3196.AGMAGleasonConicalGearMeshPowerFlow':
        '''AGMAGleasonConicalGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3196.AGMAGleasonConicalGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to AGMAGleasonConicalGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3196.AGMAGleasonConicalGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_belt_connection_power_flow(self) -> '_3201.BeltConnectionPowerFlow':
        '''BeltConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3201.BeltConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to BeltConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3201.BeltConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_bevel_differential_gear_mesh_power_flow(self) -> '_3203.BevelDifferentialGearMeshPowerFlow':
        '''BevelDifferentialGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3203.BevelDifferentialGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to BevelDifferentialGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3203.BevelDifferentialGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_bevel_gear_mesh_power_flow(self) -> '_3208.BevelGearMeshPowerFlow':
        '''BevelGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3208.BevelGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to BevelGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3208.BevelGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_clutch_connection_power_flow(self) -> '_3213.ClutchConnectionPowerFlow':
        '''ClutchConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3213.ClutchConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to ClutchConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3213.ClutchConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_concept_coupling_connection_power_flow(self) -> '_3218.ConceptCouplingConnectionPowerFlow':
        '''ConceptCouplingConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3218.ConceptCouplingConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to ConceptCouplingConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3218.ConceptCouplingConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_concept_gear_mesh_power_flow(self) -> '_3221.ConceptGearMeshPowerFlow':
        '''ConceptGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3221.ConceptGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to ConceptGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3221.ConceptGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_conical_gear_mesh_power_flow(self) -> '_3224.ConicalGearMeshPowerFlow':
        '''ConicalGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3224.ConicalGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to ConicalGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3224.ConicalGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_coupling_connection_power_flow(self) -> '_3229.CouplingConnectionPowerFlow':
        '''CouplingConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3229.CouplingConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to CouplingConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3229.CouplingConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_cvt_belt_connection_power_flow(self) -> '_3232.CVTBeltConnectionPowerFlow':
        '''CVTBeltConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3232.CVTBeltConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to CVTBeltConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3232.CVTBeltConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_cylindrical_gear_mesh_power_flow(self) -> '_3236.CylindricalGearMeshPowerFlow':
        '''CylindricalGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3236.CylindricalGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to CylindricalGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3236.CylindricalGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_face_gear_mesh_power_flow(self) -> '_3242.FaceGearMeshPowerFlow':
        '''FaceGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3242.FaceGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to FaceGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3242.FaceGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_gear_mesh_power_flow(self) -> '_3246.GearMeshPowerFlow':
        '''GearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3246.GearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to GearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3246.GearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_hypoid_gear_mesh_power_flow(self) -> '_3250.HypoidGearMeshPowerFlow':
        '''HypoidGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3250.HypoidGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to HypoidGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3250.HypoidGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_klingelnberg_cyclo_palloid_conical_gear_mesh_power_flow(self) -> '_3255.KlingelnbergCycloPalloidConicalGearMeshPowerFlow':
        '''KlingelnbergCycloPalloidConicalGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3255.KlingelnbergCycloPalloidConicalGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to KlingelnbergCycloPalloidConicalGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3255.KlingelnbergCycloPalloidConicalGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_klingelnberg_cyclo_palloid_hypoid_gear_mesh_power_flow(self) -> '_3258.KlingelnbergCycloPalloidHypoidGearMeshPowerFlow':
        '''KlingelnbergCycloPalloidHypoidGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3258.KlingelnbergCycloPalloidHypoidGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to KlingelnbergCycloPalloidHypoidGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3258.KlingelnbergCycloPalloidHypoidGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_power_flow(self) -> '_3261.KlingelnbergCycloPalloidSpiralBevelGearMeshPowerFlow':
        '''KlingelnbergCycloPalloidSpiralBevelGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3261.KlingelnbergCycloPalloidSpiralBevelGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to KlingelnbergCycloPalloidSpiralBevelGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3261.KlingelnbergCycloPalloidSpiralBevelGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_part_to_part_shear_coupling_connection_power_flow(self) -> '_3269.PartToPartShearCouplingConnectionPowerFlow':
        '''PartToPartShearCouplingConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3269.PartToPartShearCouplingConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to PartToPartShearCouplingConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3269.PartToPartShearCouplingConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_rolling_ring_connection_power_flow(self) -> '_3281.RollingRingConnectionPowerFlow':
        '''RollingRingConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3281.RollingRingConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to RollingRingConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3281.RollingRingConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_spiral_bevel_gear_mesh_power_flow(self) -> '_3288.SpiralBevelGearMeshPowerFlow':
        '''SpiralBevelGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3288.SpiralBevelGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to SpiralBevelGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3288.SpiralBevelGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_spring_damper_connection_power_flow(self) -> '_3291.SpringDamperConnectionPowerFlow':
        '''SpringDamperConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3291.SpringDamperConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to SpringDamperConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3291.SpringDamperConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_straight_bevel_diff_gear_mesh_power_flow(self) -> '_3294.StraightBevelDiffGearMeshPowerFlow':
        '''StraightBevelDiffGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3294.StraightBevelDiffGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to StraightBevelDiffGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3294.StraightBevelDiffGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_straight_bevel_gear_mesh_power_flow(self) -> '_3297.StraightBevelGearMeshPowerFlow':
        '''StraightBevelGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3297.StraightBevelGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to StraightBevelGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3297.StraightBevelGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_torque_converter_connection_power_flow(self) -> '_3307.TorqueConverterConnectionPowerFlow':
        '''TorqueConverterConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3307.TorqueConverterConnectionPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to TorqueConverterConnectionPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3307.TorqueConverterConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_worm_gear_mesh_power_flow(self) -> '_3313.WormGearMeshPowerFlow':
        '''WormGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3313.WormGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to WormGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3313.WormGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def power_flow_results_of_type_zerol_bevel_gear_mesh_power_flow(self) -> '_3316.ZerolBevelGearMeshPowerFlow':
        '''ZerolBevelGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3316.ZerolBevelGearMeshPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to ZerolBevelGearMeshPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new(_3316.ZerolBevelGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None



'''_33.py

ShaftRadialHole
'''


from typing import Callable

from mastapy._internal import constructor
from mastapy.shafts import _40, _22
from mastapy._internal.python_net import python_net_import

_SHAFT_RADIAL_HOLE = python_net_import('SMT.MastaAPI.Shafts', 'ShaftRadialHole')


__docformat__ = 'restructuredtext en'
__all__ = ('ShaftRadialHole',)


class ShaftRadialHole(_22.ShaftFeature):
    '''ShaftRadialHole

    This is a mastapy class.
    '''

    TYPE = _SHAFT_RADIAL_HOLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ShaftRadialHole.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def add_new_radial_hole(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'AddNewRadialHole' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AddNewRadialHole

    @property
    def angle(self) -> 'float':
        '''float: 'Angle' is the original name of this property.'''

        return self.wrapped.Angle

    @angle.setter
    def angle(self, value: 'float'):
        self.wrapped.Angle = float(value) if value else 0.0

    @property
    def diameter(self) -> 'float':
        '''float: 'Diameter' is the original name of this property.'''

        return self.wrapped.Diameter

    @diameter.setter
    def diameter(self, value: 'float'):
        self.wrapped.Diameter = float(value) if value else 0.0

    @property
    def surface_roughness(self) -> '_40.ShaftSurfaceRoughness':
        '''ShaftSurfaceRoughness: 'SurfaceRoughness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_40.ShaftSurfaceRoughness)(self.wrapped.SurfaceRoughness) if self.wrapped.SurfaceRoughness else None



'''_5316.py

KlingelnbergCycloPalloidHypoidGearSetGearWhineAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2056
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6122
from mastapy.system_model.analyses_and_results.system_deflections import _2258
from mastapy.system_model.analyses_and_results.gear_whine_analyses import _5314, _5315, _5313
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses', 'KlingelnbergCycloPalloidHypoidGearSetGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidHypoidGearSetGearWhineAnalysis',)


class KlingelnbergCycloPalloidHypoidGearSetGearWhineAnalysis(_5313.KlingelnbergCycloPalloidConicalGearSetGearWhineAnalysis):
    '''KlingelnbergCycloPalloidHypoidGearSetGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidHypoidGearSetGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_2056.KlingelnbergCycloPalloidHypoidGearSet':
        '''KlingelnbergCycloPalloidHypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2056.KlingelnbergCycloPalloidHypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6122.KlingelnbergCycloPalloidHypoidGearSetLoadCase':
        '''KlingelnbergCycloPalloidHypoidGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6122.KlingelnbergCycloPalloidHypoidGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def system_deflection_results(self) -> '_2258.KlingelnbergCycloPalloidHypoidGearSetSystemDeflection':
        '''KlingelnbergCycloPalloidHypoidGearSetSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2258.KlingelnbergCycloPalloidHypoidGearSetSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def gears_gear_whine_analysis(self) -> 'List[_5314.KlingelnbergCycloPalloidHypoidGearGearWhineAnalysis]':
        '''List[KlingelnbergCycloPalloidHypoidGearGearWhineAnalysis]: 'GearsGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearsGearWhineAnalysis, constructor.new(_5314.KlingelnbergCycloPalloidHypoidGearGearWhineAnalysis))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gears_gear_whine_analysis(self) -> 'List[_5314.KlingelnbergCycloPalloidHypoidGearGearWhineAnalysis]':
        '''List[KlingelnbergCycloPalloidHypoidGearGearWhineAnalysis]: 'KlingelnbergCycloPalloidHypoidGearsGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidGearsGearWhineAnalysis, constructor.new(_5314.KlingelnbergCycloPalloidHypoidGearGearWhineAnalysis))
        return value

    @property
    def meshes_gear_whine_analysis(self) -> 'List[_5315.KlingelnbergCycloPalloidHypoidGearMeshGearWhineAnalysis]':
        '''List[KlingelnbergCycloPalloidHypoidGearMeshGearWhineAnalysis]: 'MeshesGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshesGearWhineAnalysis, constructor.new(_5315.KlingelnbergCycloPalloidHypoidGearMeshGearWhineAnalysis))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_meshes_gear_whine_analysis(self) -> 'List[_5315.KlingelnbergCycloPalloidHypoidGearMeshGearWhineAnalysis]':
        '''List[KlingelnbergCycloPalloidHypoidGearMeshGearWhineAnalysis]: 'KlingelnbergCycloPalloidHypoidMeshesGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidMeshesGearWhineAnalysis, constructor.new(_5315.KlingelnbergCycloPalloidHypoidGearMeshGearWhineAnalysis))
        return value



'''_4894.py

MountableComponentCompoundModalAnalysis
'''


from mastapy.system_model.analyses_and_results.modal_analyses.compound import _4846
from mastapy._internal.python_net import python_net_import

_MOUNTABLE_COMPONENT_COMPOUND_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Compound', 'MountableComponentCompoundModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('MountableComponentCompoundModalAnalysis',)


class MountableComponentCompoundModalAnalysis(_4846.ComponentCompoundModalAnalysis):
    '''MountableComponentCompoundModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _MOUNTABLE_COMPONENT_COMPOUND_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'MountableComponentCompoundModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)



'''_5726.py

RollingRingAssemblyCompoundGearWhineAnalysis
'''


from typing import List

from mastapy.system_model.part_model.couplings import _2109
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.gear_whine_analyses import _5335
from mastapy.system_model.analyses_and_results.gear_whine_analyses.compound import _5733
from mastapy._internal.python_net import python_net_import

_ROLLING_RING_ASSEMBLY_COMPOUND_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses.Compound', 'RollingRingAssemblyCompoundGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('RollingRingAssemblyCompoundGearWhineAnalysis',)


class RollingRingAssemblyCompoundGearWhineAnalysis(_5733.SpecialisedAssemblyCompoundGearWhineAnalysis):
    '''RollingRingAssemblyCompoundGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _ROLLING_RING_ASSEMBLY_COMPOUND_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollingRingAssemblyCompoundGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2109.RollingRingAssembly':
        '''RollingRingAssembly: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2109.RollingRingAssembly)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2109.RollingRingAssembly':
        '''RollingRingAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2109.RollingRingAssembly)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def load_case_analyses_ready(self) -> 'List[_5335.RollingRingAssemblyGearWhineAnalysis]':
        '''List[RollingRingAssemblyGearWhineAnalysis]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_5335.RollingRingAssemblyGearWhineAnalysis))
        return value

    @property
    def assembly_gear_whine_analysis_load_cases(self) -> 'List[_5335.RollingRingAssemblyGearWhineAnalysis]':
        '''List[RollingRingAssemblyGearWhineAnalysis]: 'AssemblyGearWhineAnalysisLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyGearWhineAnalysisLoadCases, constructor.new(_5335.RollingRingAssemblyGearWhineAnalysis))
        return value



'''_3783.py

PowerLoadModalAnalysesAtStiffnesses
'''


from mastapy.system_model.part_model import _1991
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6144
from mastapy.system_model.analyses_and_results.modal_analyses_at_stiffnesses_ns import _3816
from mastapy._internal.python_net import python_net_import

_POWER_LOAD_MODAL_ANALYSES_AT_STIFFNESSES = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtStiffnessesNS', 'PowerLoadModalAnalysesAtStiffnesses')


__docformat__ = 'restructuredtext en'
__all__ = ('PowerLoadModalAnalysesAtStiffnesses',)


class PowerLoadModalAnalysesAtStiffnesses(_3816.VirtualComponentModalAnalysesAtStiffnesses):
    '''PowerLoadModalAnalysesAtStiffnesses

    This is a mastapy class.
    '''

    TYPE = _POWER_LOAD_MODAL_ANALYSES_AT_STIFFNESSES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PowerLoadModalAnalysesAtStiffnesses.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_1991.PowerLoad':
        '''PowerLoad: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1991.PowerLoad)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6144.PowerLoadLoadCase':
        '''PowerLoadLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6144.PowerLoadLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_407.py

GearManufacturingConfigurationViewModel
'''


from mastapy import _1
from mastapy._internal.python_net import python_net_import

_GEAR_MANUFACTURING_CONFIGURATION_VIEW_MODEL = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical', 'GearManufacturingConfigurationViewModel')


__docformat__ = 'restructuredtext en'
__all__ = ('GearManufacturingConfigurationViewModel',)


class GearManufacturingConfigurationViewModel(_1.APIBase):
    '''GearManufacturingConfigurationViewModel

    This is a mastapy class.
    '''

    TYPE = _GEAR_MANUFACTURING_CONFIGURATION_VIEW_MODEL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearManufacturingConfigurationViewModel.TYPE'):
        super().__init__(instance_to_wrap)



'''_1800.py

OptimizationStep
'''


from mastapy._internal import constructor, conversion
from mastapy.system_model.optimization import _1799
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_OPTIMIZATION_STEP = python_net_import('SMT.MastaAPI.SystemModel.Optimization', 'OptimizationStep')


__docformat__ = 'restructuredtext en'
__all__ = ('OptimizationStep',)


class OptimizationStep(_1.APIBase):
    '''OptimizationStep

    This is a mastapy class.
    '''

    TYPE = _OPTIMIZATION_STEP

    __hash__ = None

    def __init__(self, instance_to_wrap: 'OptimizationStep.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.'''

        return self.wrapped.Name

    @name.setter
    def name(self, value: 'str'):
        self.wrapped.Name = str(value) if value else None

    @property
    def target_edge_stress_factor(self) -> 'float':
        '''float: 'TargetEdgeStressFactor' is the original name of this property.'''

        return self.wrapped.TargetEdgeStressFactor

    @target_edge_stress_factor.setter
    def target_edge_stress_factor(self, value: 'float'):
        self.wrapped.TargetEdgeStressFactor = float(value) if value else 0.0

    @property
    def tolerance(self) -> 'float':
        '''float: 'Tolerance' is the original name of this property.'''

        return self.wrapped.Tolerance

    @tolerance.setter
    def tolerance(self, value: 'float'):
        self.wrapped.Tolerance = float(value) if value else 0.0

    @property
    def optimisation_target(self) -> '_1799.MicroGeometryOptimisationTarget':
        '''MicroGeometryOptimisationTarget: 'OptimisationTarget' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.OptimisationTarget)
        return constructor.new(_1799.MicroGeometryOptimisationTarget)(value) if value else None

    @optimisation_target.setter
    def optimisation_target(self, value: '_1799.MicroGeometryOptimisationTarget'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.OptimisationTarget = value



'''_1478.py

MASTAGUI
'''


from typing import Callable

from mastapy._internal import constructor
from mastapy.system_model import _1771
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_MASTAGUI = python_net_import('SMT.MastaAPI.UtilityGUI', 'MASTAGUI')


__docformat__ = 'restructuredtext en'
__all__ = ('MASTAGUI',)


class MASTAGUI(_1.APIBase):
    '''MASTAGUI

    This is a mastapy class.
    '''

    TYPE = _MASTAGUI

    __hash__ = None

    def __init__(self, instance_to_wrap: 'MASTAGUI.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def resume(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'Resume' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Resume

    @property
    def is_paused(self) -> 'bool':
        '''bool: 'IsPaused' is the original name of this property.'''

        return self.wrapped.IsPaused

    @is_paused.setter
    def is_paused(self, value: 'bool'):
        self.wrapped.IsPaused = bool(value) if value else False

    @property
    def pause(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'Pause' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Pause

    def open_design_in_new_tab(self, design: '_1771.Design'):
        ''' 'OpenDesignInNewTab' is the original name of this method.

        Args:
            design (mastapy.system_model.Design)
        '''

        self.wrapped.OpenDesignInNewTab(design.wrapped if design else None)

    def select_tab(self, tab_text: 'str'):
        ''' 'SelectTab' is the original name of this method.

        Args:
            tab_text (str)
        '''

        tab_text = str(tab_text)
        self.wrapped.SelectTab(tab_text if tab_text else None)



'''_3949.py

AssemblyModalAnalysesAtSpeeds
'''


from typing import List

from mastapy.system_model.part_model import _1958
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6031
from mastapy.system_model.analyses_and_results.modal_analyses_at_speeds_ns import (
    _3950, _3952, _3955, _3962,
    _3961, _3965, _3970, _3973,
    _3983, _3987, _3994, _3995,
    _4002, _4003, _4010, _4013,
    _4014, _4015, _4019, _4023,
    _4026, _4027, _4028, _4034,
    _4030, _4035, _4040, _4043,
    _4047, _4050, _4054, _4058,
    _4061, _4065, _4068, _3944
)
from mastapy._internal.python_net import python_net_import

_ASSEMBLY_MODAL_ANALYSES_AT_SPEEDS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtSpeedsNS', 'AssemblyModalAnalysesAtSpeeds')


__docformat__ = 'restructuredtext en'
__all__ = ('AssemblyModalAnalysesAtSpeeds',)


class AssemblyModalAnalysesAtSpeeds(_3944.AbstractAssemblyModalAnalysesAtSpeeds):
    '''AssemblyModalAnalysesAtSpeeds

    This is a mastapy class.
    '''

    TYPE = _ASSEMBLY_MODAL_ANALYSES_AT_SPEEDS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'AssemblyModalAnalysesAtSpeeds.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_1958.Assembly':
        '''Assembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1958.Assembly)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6031.AssemblyLoadCase':
        '''AssemblyLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6031.AssemblyLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def bearings(self) -> 'List[_3950.BearingModalAnalysesAtSpeeds]':
        '''List[BearingModalAnalysesAtSpeeds]: 'Bearings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Bearings, constructor.new(_3950.BearingModalAnalysesAtSpeeds))
        return value

    @property
    def belt_drives(self) -> 'List[_3952.BeltDriveModalAnalysesAtSpeeds]':
        '''List[BeltDriveModalAnalysesAtSpeeds]: 'BeltDrives' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BeltDrives, constructor.new(_3952.BeltDriveModalAnalysesAtSpeeds))
        return value

    @property
    def bevel_differential_gear_sets(self) -> 'List[_3955.BevelDifferentialGearSetModalAnalysesAtSpeeds]':
        '''List[BevelDifferentialGearSetModalAnalysesAtSpeeds]: 'BevelDifferentialGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialGearSets, constructor.new(_3955.BevelDifferentialGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def bolts(self) -> 'List[_3962.BoltModalAnalysesAtSpeeds]':
        '''List[BoltModalAnalysesAtSpeeds]: 'Bolts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Bolts, constructor.new(_3962.BoltModalAnalysesAtSpeeds))
        return value

    @property
    def bolted_joints(self) -> 'List[_3961.BoltedJointModalAnalysesAtSpeeds]':
        '''List[BoltedJointModalAnalysesAtSpeeds]: 'BoltedJoints' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BoltedJoints, constructor.new(_3961.BoltedJointModalAnalysesAtSpeeds))
        return value

    @property
    def clutches(self) -> 'List[_3965.ClutchModalAnalysesAtSpeeds]':
        '''List[ClutchModalAnalysesAtSpeeds]: 'Clutches' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Clutches, constructor.new(_3965.ClutchModalAnalysesAtSpeeds))
        return value

    @property
    def concept_couplings(self) -> 'List[_3970.ConceptCouplingModalAnalysesAtSpeeds]':
        '''List[ConceptCouplingModalAnalysesAtSpeeds]: 'ConceptCouplings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptCouplings, constructor.new(_3970.ConceptCouplingModalAnalysesAtSpeeds))
        return value

    @property
    def concept_gear_sets(self) -> 'List[_3973.ConceptGearSetModalAnalysesAtSpeeds]':
        '''List[ConceptGearSetModalAnalysesAtSpeeds]: 'ConceptGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptGearSets, constructor.new(_3973.ConceptGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def cv_ts(self) -> 'List[_3983.CVTModalAnalysesAtSpeeds]':
        '''List[CVTModalAnalysesAtSpeeds]: 'CVTs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CVTs, constructor.new(_3983.CVTModalAnalysesAtSpeeds))
        return value

    @property
    def cylindrical_gear_sets(self) -> 'List[_3987.CylindricalGearSetModalAnalysesAtSpeeds]':
        '''List[CylindricalGearSetModalAnalysesAtSpeeds]: 'CylindricalGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalGearSets, constructor.new(_3987.CylindricalGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def face_gear_sets(self) -> 'List[_3994.FaceGearSetModalAnalysesAtSpeeds]':
        '''List[FaceGearSetModalAnalysesAtSpeeds]: 'FaceGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.FaceGearSets, constructor.new(_3994.FaceGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def flexible_pin_assemblies(self) -> 'List[_3995.FlexiblePinAssemblyModalAnalysesAtSpeeds]':
        '''List[FlexiblePinAssemblyModalAnalysesAtSpeeds]: 'FlexiblePinAssemblies' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.FlexiblePinAssemblies, constructor.new(_3995.FlexiblePinAssemblyModalAnalysesAtSpeeds))
        return value

    @property
    def hypoid_gear_sets(self) -> 'List[_4002.HypoidGearSetModalAnalysesAtSpeeds]':
        '''List[HypoidGearSetModalAnalysesAtSpeeds]: 'HypoidGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidGearSets, constructor.new(_4002.HypoidGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def imported_fe_components(self) -> 'List[_4003.ImportedFEComponentModalAnalysesAtSpeeds]':
        '''List[ImportedFEComponentModalAnalysesAtSpeeds]: 'ImportedFEComponents' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ImportedFEComponents, constructor.new(_4003.ImportedFEComponentModalAnalysesAtSpeeds))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_sets(self) -> 'List[_4010.KlingelnbergCycloPalloidHypoidGearSetModalAnalysesAtSpeeds]':
        '''List[KlingelnbergCycloPalloidHypoidGearSetModalAnalysesAtSpeeds]: 'KlingelnbergCycloPalloidHypoidGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidGearSets, constructor.new(_4010.KlingelnbergCycloPalloidHypoidGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_sets(self) -> 'List[_4013.KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysesAtSpeeds]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysesAtSpeeds]: 'KlingelnbergCycloPalloidSpiralBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSets, constructor.new(_4013.KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def mass_discs(self) -> 'List[_4014.MassDiscModalAnalysesAtSpeeds]':
        '''List[MassDiscModalAnalysesAtSpeeds]: 'MassDiscs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MassDiscs, constructor.new(_4014.MassDiscModalAnalysesAtSpeeds))
        return value

    @property
    def measurement_components(self) -> 'List[_4015.MeasurementComponentModalAnalysesAtSpeeds]':
        '''List[MeasurementComponentModalAnalysesAtSpeeds]: 'MeasurementComponents' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeasurementComponents, constructor.new(_4015.MeasurementComponentModalAnalysesAtSpeeds))
        return value

    @property
    def oil_seals(self) -> 'List[_4019.OilSealModalAnalysesAtSpeeds]':
        '''List[OilSealModalAnalysesAtSpeeds]: 'OilSeals' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.OilSeals, constructor.new(_4019.OilSealModalAnalysesAtSpeeds))
        return value

    @property
    def part_to_part_shear_couplings(self) -> 'List[_4023.PartToPartShearCouplingModalAnalysesAtSpeeds]':
        '''List[PartToPartShearCouplingModalAnalysesAtSpeeds]: 'PartToPartShearCouplings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PartToPartShearCouplings, constructor.new(_4023.PartToPartShearCouplingModalAnalysesAtSpeeds))
        return value

    @property
    def planet_carriers(self) -> 'List[_4026.PlanetCarrierModalAnalysesAtSpeeds]':
        '''List[PlanetCarrierModalAnalysesAtSpeeds]: 'PlanetCarriers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PlanetCarriers, constructor.new(_4026.PlanetCarrierModalAnalysesAtSpeeds))
        return value

    @property
    def point_loads(self) -> 'List[_4027.PointLoadModalAnalysesAtSpeeds]':
        '''List[PointLoadModalAnalysesAtSpeeds]: 'PointLoads' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PointLoads, constructor.new(_4027.PointLoadModalAnalysesAtSpeeds))
        return value

    @property
    def power_loads(self) -> 'List[_4028.PowerLoadModalAnalysesAtSpeeds]':
        '''List[PowerLoadModalAnalysesAtSpeeds]: 'PowerLoads' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PowerLoads, constructor.new(_4028.PowerLoadModalAnalysesAtSpeeds))
        return value

    @property
    def shaft_hub_connections(self) -> 'List[_4034.ShaftHubConnectionModalAnalysesAtSpeeds]':
        '''List[ShaftHubConnectionModalAnalysesAtSpeeds]: 'ShaftHubConnections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ShaftHubConnections, constructor.new(_4034.ShaftHubConnectionModalAnalysesAtSpeeds))
        return value

    @property
    def rolling_ring_assemblies(self) -> 'List[_4030.RollingRingAssemblyModalAnalysesAtSpeeds]':
        '''List[RollingRingAssemblyModalAnalysesAtSpeeds]: 'RollingRingAssemblies' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.RollingRingAssemblies, constructor.new(_4030.RollingRingAssemblyModalAnalysesAtSpeeds))
        return value

    @property
    def shafts(self) -> 'List[_4035.ShaftModalAnalysesAtSpeeds]':
        '''List[ShaftModalAnalysesAtSpeeds]: 'Shafts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Shafts, constructor.new(_4035.ShaftModalAnalysesAtSpeeds))
        return value

    @property
    def spiral_bevel_gear_sets(self) -> 'List[_4040.SpiralBevelGearSetModalAnalysesAtSpeeds]':
        '''List[SpiralBevelGearSetModalAnalysesAtSpeeds]: 'SpiralBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpiralBevelGearSets, constructor.new(_4040.SpiralBevelGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def spring_dampers(self) -> 'List[_4043.SpringDamperModalAnalysesAtSpeeds]':
        '''List[SpringDamperModalAnalysesAtSpeeds]: 'SpringDampers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpringDampers, constructor.new(_4043.SpringDamperModalAnalysesAtSpeeds))
        return value

    @property
    def straight_bevel_diff_gear_sets(self) -> 'List[_4047.StraightBevelDiffGearSetModalAnalysesAtSpeeds]':
        '''List[StraightBevelDiffGearSetModalAnalysesAtSpeeds]: 'StraightBevelDiffGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffGearSets, constructor.new(_4047.StraightBevelDiffGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def straight_bevel_gear_sets(self) -> 'List[_4050.StraightBevelGearSetModalAnalysesAtSpeeds]':
        '''List[StraightBevelGearSetModalAnalysesAtSpeeds]: 'StraightBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelGearSets, constructor.new(_4050.StraightBevelGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def synchronisers(self) -> 'List[_4054.SynchroniserModalAnalysesAtSpeeds]':
        '''List[SynchroniserModalAnalysesAtSpeeds]: 'Synchronisers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Synchronisers, constructor.new(_4054.SynchroniserModalAnalysesAtSpeeds))
        return value

    @property
    def torque_converters(self) -> 'List[_4058.TorqueConverterModalAnalysesAtSpeeds]':
        '''List[TorqueConverterModalAnalysesAtSpeeds]: 'TorqueConverters' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.TorqueConverters, constructor.new(_4058.TorqueConverterModalAnalysesAtSpeeds))
        return value

    @property
    def unbalanced_masses(self) -> 'List[_4061.UnbalancedMassModalAnalysesAtSpeeds]':
        '''List[UnbalancedMassModalAnalysesAtSpeeds]: 'UnbalancedMasses' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.UnbalancedMasses, constructor.new(_4061.UnbalancedMassModalAnalysesAtSpeeds))
        return value

    @property
    def worm_gear_sets(self) -> 'List[_4065.WormGearSetModalAnalysesAtSpeeds]':
        '''List[WormGearSetModalAnalysesAtSpeeds]: 'WormGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormGearSets, constructor.new(_4065.WormGearSetModalAnalysesAtSpeeds))
        return value

    @property
    def zerol_bevel_gear_sets(self) -> 'List[_4068.ZerolBevelGearSetModalAnalysesAtSpeeds]':
        '''List[ZerolBevelGearSetModalAnalysesAtSpeeds]: 'ZerolBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelGearSets, constructor.new(_4068.ZerolBevelGearSetModalAnalysesAtSpeeds))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5089 import AbstractAssemblyCompoundMultiBodyDynamicsAnalysis
    from ._5090 import AbstractShaftOrHousingCompoundMultiBodyDynamicsAnalysis
    from ._5091 import AGMAGleasonConicalGearCompoundMultiBodyDynamicsAnalysis
    from ._5092 import AGMAGleasonConicalGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5093 import AGMAGleasonConicalGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5094 import AssemblyCompoundMultiBodyDynamicsAnalysis
    from ._5095 import BearingCompoundMultiBodyDynamicsAnalysis
    from ._5096 import BeltConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5097 import BeltDriveCompoundMultiBodyDynamicsAnalysis
    from ._5098 import BevelDifferentialGearCompoundMultiBodyDynamicsAnalysis
    from ._5099 import BevelDifferentialGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5100 import BevelDifferentialGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5101 import BevelDifferentialPlanetGearCompoundMultiBodyDynamicsAnalysis
    from ._5102 import BevelDifferentialSunGearCompoundMultiBodyDynamicsAnalysis
    from ._5103 import BevelGearCompoundMultiBodyDynamicsAnalysis
    from ._5104 import BevelGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5105 import BevelGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5106 import BoltCompoundMultiBodyDynamicsAnalysis
    from ._5107 import BoltedJointCompoundMultiBodyDynamicsAnalysis
    from ._5108 import ClutchCompoundMultiBodyDynamicsAnalysis
    from ._5109 import ClutchConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5110 import ClutchHalfCompoundMultiBodyDynamicsAnalysis
    from ._5111 import CoaxialConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5112 import ComponentCompoundMultiBodyDynamicsAnalysis
    from ._5113 import ConceptCouplingCompoundMultiBodyDynamicsAnalysis
    from ._5114 import ConceptCouplingConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5115 import ConceptCouplingHalfCompoundMultiBodyDynamicsAnalysis
    from ._5116 import ConceptGearCompoundMultiBodyDynamicsAnalysis
    from ._5117 import ConceptGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5118 import ConceptGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5119 import ConicalGearCompoundMultiBodyDynamicsAnalysis
    from ._5120 import ConicalGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5121 import ConicalGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5122 import ConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5123 import ConnectorCompoundMultiBodyDynamicsAnalysis
    from ._5124 import CouplingCompoundMultiBodyDynamicsAnalysis
    from ._5125 import CouplingConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5126 import CouplingHalfCompoundMultiBodyDynamicsAnalysis
    from ._5127 import CVTBeltConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5128 import CVTCompoundMultiBodyDynamicsAnalysis
    from ._5129 import CVTPulleyCompoundMultiBodyDynamicsAnalysis
    from ._5130 import CylindricalGearCompoundMultiBodyDynamicsAnalysis
    from ._5131 import CylindricalGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5132 import CylindricalGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5133 import CylindricalPlanetGearCompoundMultiBodyDynamicsAnalysis
    from ._5134 import DatumCompoundMultiBodyDynamicsAnalysis
    from ._5135 import ExternalCADModelCompoundMultiBodyDynamicsAnalysis
    from ._5136 import FaceGearCompoundMultiBodyDynamicsAnalysis
    from ._5137 import FaceGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5138 import FaceGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5139 import FlexiblePinAssemblyCompoundMultiBodyDynamicsAnalysis
    from ._5140 import GearCompoundMultiBodyDynamicsAnalysis
    from ._5141 import GearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5142 import GearSetCompoundMultiBodyDynamicsAnalysis
    from ._5143 import GuideDxfModelCompoundMultiBodyDynamicsAnalysis
    from ._5144 import HypoidGearCompoundMultiBodyDynamicsAnalysis
    from ._5145 import HypoidGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5146 import HypoidGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5147 import ImportedFEComponentCompoundMultiBodyDynamicsAnalysis
    from ._5148 import InterMountableComponentConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5149 import KlingelnbergCycloPalloidConicalGearCompoundMultiBodyDynamicsAnalysis
    from ._5150 import KlingelnbergCycloPalloidConicalGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5151 import KlingelnbergCycloPalloidConicalGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5152 import KlingelnbergCycloPalloidHypoidGearCompoundMultiBodyDynamicsAnalysis
    from ._5153 import KlingelnbergCycloPalloidHypoidGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5154 import KlingelnbergCycloPalloidHypoidGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5155 import KlingelnbergCycloPalloidSpiralBevelGearCompoundMultiBodyDynamicsAnalysis
    from ._5156 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5157 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5158 import MassDiscCompoundMultiBodyDynamicsAnalysis
    from ._5159 import MeasurementComponentCompoundMultiBodyDynamicsAnalysis
    from ._5160 import MountableComponentCompoundMultiBodyDynamicsAnalysis
    from ._5161 import OilSealCompoundMultiBodyDynamicsAnalysis
    from ._5162 import PartCompoundMultiBodyDynamicsAnalysis
    from ._5163 import PartToPartShearCouplingCompoundMultiBodyDynamicsAnalysis
    from ._5164 import PartToPartShearCouplingConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5165 import PartToPartShearCouplingHalfCompoundMultiBodyDynamicsAnalysis
    from ._5166 import PlanetaryConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5167 import PlanetaryGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5168 import PlanetCarrierCompoundMultiBodyDynamicsAnalysis
    from ._5169 import PointLoadCompoundMultiBodyDynamicsAnalysis
    from ._5170 import PowerLoadCompoundMultiBodyDynamicsAnalysis
    from ._5171 import PulleyCompoundMultiBodyDynamicsAnalysis
    from ._5172 import RollingRingAssemblyCompoundMultiBodyDynamicsAnalysis
    from ._5173 import RollingRingCompoundMultiBodyDynamicsAnalysis
    from ._5174 import RollingRingConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5175 import RootAssemblyCompoundMultiBodyDynamicsAnalysis
    from ._5176 import ShaftCompoundMultiBodyDynamicsAnalysis
    from ._5177 import ShaftHubConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5178 import ShaftToMountableComponentConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5179 import SpecialisedAssemblyCompoundMultiBodyDynamicsAnalysis
    from ._5180 import SpiralBevelGearCompoundMultiBodyDynamicsAnalysis
    from ._5181 import SpiralBevelGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5182 import SpiralBevelGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5183 import SpringDamperCompoundMultiBodyDynamicsAnalysis
    from ._5184 import SpringDamperConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5185 import SpringDamperHalfCompoundMultiBodyDynamicsAnalysis
    from ._5186 import StraightBevelDiffGearCompoundMultiBodyDynamicsAnalysis
    from ._5187 import StraightBevelDiffGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5188 import StraightBevelDiffGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5189 import StraightBevelGearCompoundMultiBodyDynamicsAnalysis
    from ._5190 import StraightBevelGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5191 import StraightBevelGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5192 import StraightBevelPlanetGearCompoundMultiBodyDynamicsAnalysis
    from ._5193 import StraightBevelSunGearCompoundMultiBodyDynamicsAnalysis
    from ._5194 import SynchroniserCompoundMultiBodyDynamicsAnalysis
    from ._5195 import SynchroniserHalfCompoundMultiBodyDynamicsAnalysis
    from ._5196 import SynchroniserPartCompoundMultiBodyDynamicsAnalysis
    from ._5197 import SynchroniserSleeveCompoundMultiBodyDynamicsAnalysis
    from ._5198 import TorqueConverterCompoundMultiBodyDynamicsAnalysis
    from ._5199 import TorqueConverterConnectionCompoundMultiBodyDynamicsAnalysis
    from ._5200 import TorqueConverterPumpCompoundMultiBodyDynamicsAnalysis
    from ._5201 import TorqueConverterTurbineCompoundMultiBodyDynamicsAnalysis
    from ._5202 import UnbalancedMassCompoundMultiBodyDynamicsAnalysis
    from ._5203 import VirtualComponentCompoundMultiBodyDynamicsAnalysis
    from ._5204 import WormGearCompoundMultiBodyDynamicsAnalysis
    from ._5205 import WormGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5206 import WormGearSetCompoundMultiBodyDynamicsAnalysis
    from ._5207 import ZerolBevelGearCompoundMultiBodyDynamicsAnalysis
    from ._5208 import ZerolBevelGearMeshCompoundMultiBodyDynamicsAnalysis
    from ._5209 import ZerolBevelGearSetCompoundMultiBodyDynamicsAnalysis



'''_374.py

CylindricalGearPlasticMaterialDatabase
'''


from typing import Iterable

from mastapy.gears.materials import _383
from mastapy._internal import constructor, conversion
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_PLASTIC_MATERIAL_DATABASE = python_net_import('SMT.MastaAPI.Gears.Materials', 'CylindricalGearPlasticMaterialDatabase')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearPlasticMaterialDatabase',)


class CylindricalGearPlasticMaterialDatabase(_1.APIBase):
    '''CylindricalGearPlasticMaterialDatabase

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_PLASTIC_MATERIAL_DATABASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearPlasticMaterialDatabase.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def item(self) -> '_383.PlasticCylindricalGearMaterial':
        '''PlasticCylindricalGearMaterial: 'Item' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_383.PlasticCylindricalGearMaterial)(self.wrapped.Item) if self.wrapped.Item else None

    def create(self, name: 'str') -> '_383.PlasticCylindricalGearMaterial':
        ''' 'Create' is the original name of this method.

        Args:
            name (str)

        Returns:
            mastapy.gears.materials.PlasticCylindricalGearMaterial
        '''

        name = str(name)
        method_result = self.wrapped.Create(name if name else None)
        return constructor.new(_383.PlasticCylindricalGearMaterial)(method_result) if method_result else None

    def can_be_removed(self, plastic_cylindrical_gear_material: '_383.PlasticCylindricalGearMaterial') -> 'bool':
        ''' 'CanBeRemoved' is the original name of this method.

        Args:
            plastic_cylindrical_gear_material (mastapy.gears.materials.PlasticCylindricalGearMaterial)

        Returns:
            bool
        '''

        method_result = self.wrapped.CanBeRemoved(plastic_cylindrical_gear_material.wrapped if plastic_cylindrical_gear_material else None)
        return method_result

    def rename(self, plastic_cylindrical_gear_material: '_383.PlasticCylindricalGearMaterial', new_name: 'str') -> 'bool':
        ''' 'Rename' is the original name of this method.

        Args:
            plastic_cylindrical_gear_material (mastapy.gears.materials.PlasticCylindricalGearMaterial)
            new_name (str)

        Returns:
            bool
        '''

        new_name = str(new_name)
        method_result = self.wrapped.Rename(plastic_cylindrical_gear_material.wrapped if plastic_cylindrical_gear_material else None, new_name if new_name else None)
        return method_result

    def remove(self, plastic_cylindrical_gear_material: '_383.PlasticCylindricalGearMaterial'):
        ''' 'Remove' is the original name of this method.

        Args:
            plastic_cylindrical_gear_material (mastapy.gears.materials.PlasticCylindricalGearMaterial)
        '''

        self.wrapped.Remove(plastic_cylindrical_gear_material.wrapped if plastic_cylindrical_gear_material else None)

    def get_all_items(self) -> 'Iterable[_383.PlasticCylindricalGearMaterial]':
        ''' 'GetAllItems' is the original name of this method.

        Returns:
            Iterable[mastapy.gears.materials.PlasticCylindricalGearMaterial]
        '''

        return conversion.pn_to_mp_objects_in_iterable(self.wrapped.GetAllItems(), constructor.new(_383.PlasticCylindricalGearMaterial))

    def save_changes(self, plastic_cylindrical_gear_material: '_383.PlasticCylindricalGearMaterial'):
        ''' 'SaveChanges' is the original name of this method.

        Args:
            plastic_cylindrical_gear_material (mastapy.gears.materials.PlasticCylindricalGearMaterial)
        '''

        self.wrapped.SaveChanges(plastic_cylindrical_gear_material.wrapped if plastic_cylindrical_gear_material else None)



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3823 import AbstractAssemblyCompoundModalAnalysesAtStiffnesses
    from ._3824 import AbstractShaftOrHousingCompoundModalAnalysesAtStiffnesses
    from ._3825 import AGMAGleasonConicalGearCompoundModalAnalysesAtStiffnesses
    from ._3826 import AGMAGleasonConicalGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3827 import AGMAGleasonConicalGearSetCompoundModalAnalysesAtStiffnesses
    from ._3828 import AssemblyCompoundModalAnalysesAtStiffnesses
    from ._3829 import BearingCompoundModalAnalysesAtStiffnesses
    from ._3830 import BeltConnectionCompoundModalAnalysesAtStiffnesses
    from ._3831 import BeltDriveCompoundModalAnalysesAtStiffnesses
    from ._3832 import BevelDifferentialGearCompoundModalAnalysesAtStiffnesses
    from ._3833 import BevelDifferentialGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3834 import BevelDifferentialGearSetCompoundModalAnalysesAtStiffnesses
    from ._3835 import BevelDifferentialPlanetGearCompoundModalAnalysesAtStiffnesses
    from ._3836 import BevelDifferentialSunGearCompoundModalAnalysesAtStiffnesses
    from ._3837 import BevelGearCompoundModalAnalysesAtStiffnesses
    from ._3838 import BevelGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3839 import BevelGearSetCompoundModalAnalysesAtStiffnesses
    from ._3840 import BoltCompoundModalAnalysesAtStiffnesses
    from ._3841 import BoltedJointCompoundModalAnalysesAtStiffnesses
    from ._3842 import ClutchCompoundModalAnalysesAtStiffnesses
    from ._3843 import ClutchConnectionCompoundModalAnalysesAtStiffnesses
    from ._3844 import ClutchHalfCompoundModalAnalysesAtStiffnesses
    from ._3845 import CoaxialConnectionCompoundModalAnalysesAtStiffnesses
    from ._3846 import ComponentCompoundModalAnalysesAtStiffnesses
    from ._3847 import ConceptCouplingCompoundModalAnalysesAtStiffnesses
    from ._3848 import ConceptCouplingConnectionCompoundModalAnalysesAtStiffnesses
    from ._3849 import ConceptCouplingHalfCompoundModalAnalysesAtStiffnesses
    from ._3850 import ConceptGearCompoundModalAnalysesAtStiffnesses
    from ._3851 import ConceptGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3852 import ConceptGearSetCompoundModalAnalysesAtStiffnesses
    from ._3853 import ConicalGearCompoundModalAnalysesAtStiffnesses
    from ._3854 import ConicalGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3855 import ConicalGearSetCompoundModalAnalysesAtStiffnesses
    from ._3856 import ConnectionCompoundModalAnalysesAtStiffnesses
    from ._3857 import ConnectorCompoundModalAnalysesAtStiffnesses
    from ._3858 import CouplingCompoundModalAnalysesAtStiffnesses
    from ._3859 import CouplingConnectionCompoundModalAnalysesAtStiffnesses
    from ._3860 import CouplingHalfCompoundModalAnalysesAtStiffnesses
    from ._3861 import CVTBeltConnectionCompoundModalAnalysesAtStiffnesses
    from ._3862 import CVTCompoundModalAnalysesAtStiffnesses
    from ._3863 import CVTPulleyCompoundModalAnalysesAtStiffnesses
    from ._3864 import CylindricalGearCompoundModalAnalysesAtStiffnesses
    from ._3865 import CylindricalGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3866 import CylindricalGearSetCompoundModalAnalysesAtStiffnesses
    from ._3867 import CylindricalPlanetGearCompoundModalAnalysesAtStiffnesses
    from ._3868 import DatumCompoundModalAnalysesAtStiffnesses
    from ._3869 import ExternalCADModelCompoundModalAnalysesAtStiffnesses
    from ._3870 import FaceGearCompoundModalAnalysesAtStiffnesses
    from ._3871 import FaceGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3872 import FaceGearSetCompoundModalAnalysesAtStiffnesses
    from ._3873 import FlexiblePinAssemblyCompoundModalAnalysesAtStiffnesses
    from ._3874 import GearCompoundModalAnalysesAtStiffnesses
    from ._3875 import GearMeshCompoundModalAnalysesAtStiffnesses
    from ._3876 import GearSetCompoundModalAnalysesAtStiffnesses
    from ._3877 import GuideDxfModelCompoundModalAnalysesAtStiffnesses
    from ._3878 import HypoidGearCompoundModalAnalysesAtStiffnesses
    from ._3879 import HypoidGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3880 import HypoidGearSetCompoundModalAnalysesAtStiffnesses
    from ._3881 import ImportedFEComponentCompoundModalAnalysesAtStiffnesses
    from ._3882 import InterMountableComponentConnectionCompoundModalAnalysesAtStiffnesses
    from ._3883 import KlingelnbergCycloPalloidConicalGearCompoundModalAnalysesAtStiffnesses
    from ._3884 import KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3885 import KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysesAtStiffnesses
    from ._3886 import KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysesAtStiffnesses
    from ._3887 import KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3888 import KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysesAtStiffnesses
    from ._3889 import KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysesAtStiffnesses
    from ._3890 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3891 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysesAtStiffnesses
    from ._3892 import MassDiscCompoundModalAnalysesAtStiffnesses
    from ._3893 import MeasurementComponentCompoundModalAnalysesAtStiffnesses
    from ._3894 import MountableComponentCompoundModalAnalysesAtStiffnesses
    from ._3895 import OilSealCompoundModalAnalysesAtStiffnesses
    from ._3896 import PartCompoundModalAnalysesAtStiffnesses
    from ._3897 import PartToPartShearCouplingCompoundModalAnalysesAtStiffnesses
    from ._3898 import PartToPartShearCouplingConnectionCompoundModalAnalysesAtStiffnesses
    from ._3899 import PartToPartShearCouplingHalfCompoundModalAnalysesAtStiffnesses
    from ._3900 import PlanetaryConnectionCompoundModalAnalysesAtStiffnesses
    from ._3901 import PlanetaryGearSetCompoundModalAnalysesAtStiffnesses
    from ._3902 import PlanetCarrierCompoundModalAnalysesAtStiffnesses
    from ._3903 import PointLoadCompoundModalAnalysesAtStiffnesses
    from ._3904 import PowerLoadCompoundModalAnalysesAtStiffnesses
    from ._3905 import PulleyCompoundModalAnalysesAtStiffnesses
    from ._3906 import RollingRingAssemblyCompoundModalAnalysesAtStiffnesses
    from ._3907 import RollingRingCompoundModalAnalysesAtStiffnesses
    from ._3908 import RollingRingConnectionCompoundModalAnalysesAtStiffnesses
    from ._3909 import RootAssemblyCompoundModalAnalysesAtStiffnesses
    from ._3910 import ShaftCompoundModalAnalysesAtStiffnesses
    from ._3911 import ShaftHubConnectionCompoundModalAnalysesAtStiffnesses
    from ._3912 import ShaftToMountableComponentConnectionCompoundModalAnalysesAtStiffnesses
    from ._3913 import SpecialisedAssemblyCompoundModalAnalysesAtStiffnesses
    from ._3914 import SpiralBevelGearCompoundModalAnalysesAtStiffnesses
    from ._3915 import SpiralBevelGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3916 import SpiralBevelGearSetCompoundModalAnalysesAtStiffnesses
    from ._3917 import SpringDamperCompoundModalAnalysesAtStiffnesses
    from ._3918 import SpringDamperConnectionCompoundModalAnalysesAtStiffnesses
    from ._3919 import SpringDamperHalfCompoundModalAnalysesAtStiffnesses
    from ._3920 import StraightBevelDiffGearCompoundModalAnalysesAtStiffnesses
    from ._3921 import StraightBevelDiffGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3922 import StraightBevelDiffGearSetCompoundModalAnalysesAtStiffnesses
    from ._3923 import StraightBevelGearCompoundModalAnalysesAtStiffnesses
    from ._3924 import StraightBevelGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3925 import StraightBevelGearSetCompoundModalAnalysesAtStiffnesses
    from ._3926 import StraightBevelPlanetGearCompoundModalAnalysesAtStiffnesses
    from ._3927 import StraightBevelSunGearCompoundModalAnalysesAtStiffnesses
    from ._3928 import SynchroniserCompoundModalAnalysesAtStiffnesses
    from ._3929 import SynchroniserHalfCompoundModalAnalysesAtStiffnesses
    from ._3930 import SynchroniserPartCompoundModalAnalysesAtStiffnesses
    from ._3931 import SynchroniserSleeveCompoundModalAnalysesAtStiffnesses
    from ._3932 import TorqueConverterCompoundModalAnalysesAtStiffnesses
    from ._3933 import TorqueConverterConnectionCompoundModalAnalysesAtStiffnesses
    from ._3934 import TorqueConverterPumpCompoundModalAnalysesAtStiffnesses
    from ._3935 import TorqueConverterTurbineCompoundModalAnalysesAtStiffnesses
    from ._3936 import UnbalancedMassCompoundModalAnalysesAtStiffnesses
    from ._3937 import VirtualComponentCompoundModalAnalysesAtStiffnesses
    from ._3938 import WormGearCompoundModalAnalysesAtStiffnesses
    from ._3939 import WormGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3940 import WormGearSetCompoundModalAnalysesAtStiffnesses
    from ._3941 import ZerolBevelGearCompoundModalAnalysesAtStiffnesses
    from ._3942 import ZerolBevelGearMeshCompoundModalAnalysesAtStiffnesses
    from ._3943 import ZerolBevelGearSetCompoundModalAnalysesAtStiffnesses



'''_1909.py

FEExportSettings
'''


from mastapy import _1
from mastapy._internal.python_net import python_net_import

_FE_EXPORT_SETTINGS = python_net_import('SMT.MastaAPI.SystemModel.ImportedFEs', 'FEExportSettings')


__docformat__ = 'restructuredtext en'
__all__ = ('FEExportSettings',)


class FEExportSettings(_1.APIBase):
    '''FEExportSettings

    This is a mastapy class.
    '''

    TYPE = _FE_EXPORT_SETTINGS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FEExportSettings.TYPE'):
        super().__init__(instance_to_wrap)



'''_5037.py

PowerLoadMultiBodyDynamicsAnalysis
'''


from mastapy._internal import constructor
from mastapy.system_model.part_model import _1991
from mastapy.system_model.analyses_and_results.static_loads import _6144
from mastapy.system_model.analyses_and_results.mbd_analyses import _5075
from mastapy._internal.python_net import python_net_import

_POWER_LOAD_MULTI_BODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'PowerLoadMultiBodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('PowerLoadMultiBodyDynamicsAnalysis',)


class PowerLoadMultiBodyDynamicsAnalysis(_5075.VirtualComponentMultiBodyDynamicsAnalysis):
    '''PowerLoadMultiBodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _POWER_LOAD_MULTI_BODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PowerLoadMultiBodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def angular_jerk_rate_of_change_of_acceleration(self) -> 'float':
        '''float: 'AngularJerkRateOfChangeOfAcceleration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AngularJerkRateOfChangeOfAcceleration

    @property
    def energy_input(self) -> 'float':
        '''float: 'EnergyInput' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EnergyInput

    @property
    def fuel_consumption_instantaneous(self) -> 'float':
        '''float: 'FuelConsumptionInstantaneous' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FuelConsumptionInstantaneous

    @property
    def total_fuel_consumed(self) -> 'float':
        '''float: 'TotalFuelConsumed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalFuelConsumed

    @property
    def controller_torque(self) -> 'float':
        '''float: 'ControllerTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ControllerTorque

    @property
    def unfiltered_controller_torque(self) -> 'float':
        '''float: 'UnfilteredControllerTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.UnfilteredControllerTorque

    @property
    def filtered_engine_throttle(self) -> 'float':
        '''float: 'FilteredEngineThrottle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FilteredEngineThrottle

    @property
    def engine_throttle_position_over_time(self) -> 'float':
        '''float: 'EngineThrottlePositionOverTime' is the original name of this property.'''

        return self.wrapped.EngineThrottlePositionOverTime

    @engine_throttle_position_over_time.setter
    def engine_throttle_position_over_time(self, value: 'float'):
        self.wrapped.EngineThrottlePositionOverTime = float(value) if value else 0.0

    @property
    def engine_throttle_from_interface(self) -> 'float':
        '''float: 'EngineThrottleFromInterface' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EngineThrottleFromInterface

    @property
    def error_in_engine_idle_speed(self) -> 'float':
        '''float: 'ErrorInEngineIdleSpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ErrorInEngineIdleSpeed

    @property
    def engine_idle_speed_control_enabled(self) -> 'bool':
        '''bool: 'EngineIdleSpeedControlEnabled' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EngineIdleSpeedControlEnabled

    @property
    def applied_torque(self) -> 'float':
        '''float: 'AppliedTorque' is the original name of this property.'''

        return self.wrapped.AppliedTorque

    @applied_torque.setter
    def applied_torque(self, value: 'float'):
        self.wrapped.AppliedTorque = float(value) if value else 0.0

    @property
    def interface_input_torque_used_in_solver(self) -> 'float':
        '''float: 'InterfaceInputTorqueUsedInSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InterfaceInputTorqueUsedInSolver

    @property
    def drag_torque(self) -> 'float':
        '''float: 'DragTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DragTorque

    @property
    def elastic_torque(self) -> 'float':
        '''float: 'ElasticTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticTorque

    @property
    def total_torque(self) -> 'float':
        '''float: 'TotalTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalTorque

    @property
    def torque_from_vehicle(self) -> 'float':
        '''float: 'TorqueFromVehicle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TorqueFromVehicle

    @property
    def torque_on_each_wheel(self) -> 'float':
        '''float: 'TorqueOnEachWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TorqueOnEachWheel

    @property
    def is_locked(self) -> 'bool':
        '''bool: 'IsLocked' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsLocked

    @property
    def power(self) -> 'float':
        '''float: 'Power' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Power

    @property
    def is_wheel_using_static_friction(self) -> 'bool':
        '''bool: 'IsWheelUsingStaticFriction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsWheelUsingStaticFriction

    @property
    def longitudinal_slip_ratio(self) -> 'float':
        '''float: 'LongitudinalSlipRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LongitudinalSlipRatio

    @property
    def current_coefficient_of_friction_with_ground(self) -> 'float':
        '''float: 'CurrentCoefficientOfFrictionWithGround' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CurrentCoefficientOfFrictionWithGround

    @property
    def error_in_target_speed(self) -> 'float':
        '''float: 'ErrorInTargetSpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ErrorInTargetSpeed

    @property
    def component_design(self) -> '_1991.PowerLoad':
        '''PowerLoad: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1991.PowerLoad)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6144.PowerLoadLoadCase':
        '''PowerLoadLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6144.PowerLoadLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_4232.py

CylindricalGearModalAnalysisAtAStiffness
'''


from typing import List

from mastapy.system_model.part_model.gears import _2042
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6069
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import _4243
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness', 'CylindricalGearModalAnalysisAtAStiffness')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearModalAnalysisAtAStiffness',)


class CylindricalGearModalAnalysisAtAStiffness(_4243.GearModalAnalysisAtAStiffness):
    '''CylindricalGearModalAnalysisAtAStiffness

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_MODAL_ANALYSIS_AT_A_STIFFNESS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearModalAnalysisAtAStiffness.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2042.CylindricalGear':
        '''CylindricalGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2042.CylindricalGear)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6069.CylindricalGearLoadCase':
        '''CylindricalGearLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6069.CylindricalGearLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def planetaries(self) -> 'List[CylindricalGearModalAnalysisAtAStiffness]':
        '''List[CylindricalGearModalAnalysisAtAStiffness]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(CylindricalGearModalAnalysisAtAStiffness))
        return value



'''_763.py

CylindricalGearAbstractRack
'''


from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy.gears.gear_designs.cylindrical import _767
from mastapy.gears.manufacturing.cylindrical.cutters import _510
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_ABSTRACT_RACK = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'CylindricalGearAbstractRack')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearAbstractRack',)


class CylindricalGearAbstractRack(_1.APIBase):
    '''CylindricalGearAbstractRack

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_ABSTRACT_RACK

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearAbstractRack.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def basic_rack_addendum_factor(self) -> 'float':
        '''float: 'BasicRackAddendumFactor' is the original name of this property.'''

        return self.wrapped.BasicRackAddendumFactor

    @basic_rack_addendum_factor.setter
    def basic_rack_addendum_factor(self, value: 'float'):
        self.wrapped.BasicRackAddendumFactor = float(value) if value else 0.0

    @property
    def basic_rack_dedendum_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'BasicRackDedendumFactor' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.BasicRackDedendumFactor) if self.wrapped.BasicRackDedendumFactor else None

    @basic_rack_dedendum_factor.setter
    def basic_rack_dedendum_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.TYPE
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.BasicRackDedendumFactor = value

    @property
    def residual_fillet_undercut(self) -> 'float':
        '''float: 'ResidualFilletUndercut' is the original name of this property.'''

        return self.wrapped.ResidualFilletUndercut

    @residual_fillet_undercut.setter
    def residual_fillet_undercut(self, value: 'float'):
        self.wrapped.ResidualFilletUndercut = float(value) if value else 0.0

    @property
    def rough_protuberance(self) -> 'float':
        '''float: 'RoughProtuberance' is the original name of this property.'''

        return self.wrapped.RoughProtuberance

    @rough_protuberance.setter
    def rough_protuberance(self, value: 'float'):
        self.wrapped.RoughProtuberance = float(value) if value else 0.0

    @property
    def residual_fillet_undercut_factor(self) -> 'float':
        '''float: 'ResidualFilletUndercutFactor' is the original name of this property.'''

        return self.wrapped.ResidualFilletUndercutFactor

    @residual_fillet_undercut_factor.setter
    def residual_fillet_undercut_factor(self, value: 'float'):
        self.wrapped.ResidualFilletUndercutFactor = float(value) if value else 0.0

    @property
    def rough_protuberance_factor(self) -> 'float':
        '''float: 'RoughProtuberanceFactor' is the original name of this property.'''

        return self.wrapped.RoughProtuberanceFactor

    @rough_protuberance_factor.setter
    def rough_protuberance_factor(self, value: 'float'):
        self.wrapped.RoughProtuberanceFactor = float(value) if value else 0.0

    @property
    def edge_radius_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'EdgeRadiusFactor' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.EdgeRadiusFactor) if self.wrapped.EdgeRadiusFactor else None

    @edge_radius_factor.setter
    def edge_radius_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.TYPE
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.EdgeRadiusFactor = value

    @property
    def use_maximum_edge_radius(self) -> 'bool':
        '''bool: 'UseMaximumEdgeRadius' is the original name of this property.'''

        return self.wrapped.UseMaximumEdgeRadius

    @use_maximum_edge_radius.setter
    def use_maximum_edge_radius(self, value: 'bool'):
        self.wrapped.UseMaximumEdgeRadius = bool(value) if value else False

    @property
    def protuberance_specification(self) -> 'CylindricalGearAbstractRack.ProtuberanceSpecificationMethod':
        '''ProtuberanceSpecificationMethod: 'ProtuberanceSpecification' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.ProtuberanceSpecification)
        return constructor.new(CylindricalGearAbstractRack.ProtuberanceSpecificationMethod)(value) if value else None

    @protuberance_specification.setter
    def protuberance_specification(self, value: 'CylindricalGearAbstractRack.ProtuberanceSpecificationMethod'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ProtuberanceSpecification = value

    @property
    def protuberance_height_factor(self) -> 'float':
        '''float: 'ProtuberanceHeightFactor' is the original name of this property.'''

        return self.wrapped.ProtuberanceHeightFactor

    @protuberance_height_factor.setter
    def protuberance_height_factor(self, value: 'float'):
        self.wrapped.ProtuberanceHeightFactor = float(value) if value else 0.0

    @property
    def protuberance_height(self) -> 'float':
        '''float: 'ProtuberanceHeight' is the original name of this property.'''

        return self.wrapped.ProtuberanceHeight

    @protuberance_height.setter
    def protuberance_height(self, value: 'float'):
        self.wrapped.ProtuberanceHeight = float(value) if value else 0.0

    @property
    def protuberance_angle(self) -> 'float':
        '''float: 'ProtuberanceAngle' is the original name of this property.'''

        return self.wrapped.ProtuberanceAngle

    @protuberance_angle.setter
    def protuberance_angle(self, value: 'float'):
        self.wrapped.ProtuberanceAngle = float(value) if value else 0.0

    @property
    def maximum_possible_cutter_edge_radius(self) -> 'float':
        '''float: 'MaximumPossibleCutterEdgeRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumPossibleCutterEdgeRadius

    @property
    def rack_undercut_clearance_normal_module(self) -> 'float':
        '''float: 'RackUndercutClearanceNormalModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RackUndercutClearanceNormalModule

    @property
    def rack_undercut_clearance(self) -> 'float':
        '''float: 'RackUndercutClearance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RackUndercutClearance

    @property
    def basic_rack_tip_thickness(self) -> 'float':
        '''float: 'BasicRackTipThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BasicRackTipThickness

    @property
    def cutter_tip_width_normal_module(self) -> 'float':
        '''float: 'CutterTipWidthNormalModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CutterTipWidthNormalModule

    @property
    def radial_chamfer_height_factor(self) -> 'float':
        '''float: 'RadialChamferHeightFactor' is the original name of this property.'''

        return self.wrapped.RadialChamferHeightFactor

    @radial_chamfer_height_factor.setter
    def radial_chamfer_height_factor(self, value: 'float'):
        self.wrapped.RadialChamferHeightFactor = float(value) if value else 0.0

    @property
    def radial_chamfer_height(self) -> 'float':
        '''float: 'RadialChamferHeight' is the original name of this property.'''

        return self.wrapped.RadialChamferHeight

    @radial_chamfer_height.setter
    def radial_chamfer_height(self, value: 'float'):
        self.wrapped.RadialChamferHeight = float(value) if value else 0.0

    @property
    def diameter_chamfer_height(self) -> 'float':
        '''float: 'DiameterChamferHeight' is the original name of this property.'''

        return self.wrapped.DiameterChamferHeight

    @diameter_chamfer_height.setter
    def diameter_chamfer_height(self, value: 'float'):
        self.wrapped.DiameterChamferHeight = float(value) if value else 0.0

    @property
    def chamfer_angle(self) -> 'float':
        '''float: 'ChamferAngle' is the original name of this property.'''

        return self.wrapped.ChamferAngle

    @chamfer_angle.setter
    def chamfer_angle(self, value: 'float'):
        self.wrapped.ChamferAngle = float(value) if value else 0.0

    @property
    def chamfer_angle_in_transverse_plane(self) -> 'float':
        '''float: 'ChamferAngleInTransversePlane' is the original name of this property.'''

        return self.wrapped.ChamferAngleInTransversePlane

    @chamfer_angle_in_transverse_plane.setter
    def chamfer_angle_in_transverse_plane(self, value: 'float'):
        self.wrapped.ChamferAngleInTransversePlane = float(value) if value else 0.0

    @property
    def edge_radius(self) -> 'float':
        '''float: 'EdgeRadius' is the original name of this property.'''

        return self.wrapped.EdgeRadius

    @edge_radius.setter
    def edge_radius(self, value: 'float'):
        self.wrapped.EdgeRadius = float(value) if value else 0.0

    @property
    def gear(self) -> '_767.CylindricalGearDesign':
        '''CylindricalGearDesign: 'Gear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_767.CylindricalGearDesign)(self.wrapped.Gear) if self.wrapped.Gear else None

    @property
    def shaper_for_agma_rating(self) -> '_510.CylindricalGearShaper':
        '''CylindricalGearShaper: 'ShaperForAGMARating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_510.CylindricalGearShaper)(self.wrapped.ShaperForAGMARating) if self.wrapped.ShaperForAGMARating else None



'''_48.py

AGMAMaterialApplications
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_AGMA_MATERIAL_APPLICATIONS = python_net_import('SMT.MastaAPI.Materials', 'AGMAMaterialApplications')


__docformat__ = 'restructuredtext en'
__all__ = ('AGMAMaterialApplications',)


class AGMAMaterialApplications(Enum):
    '''AGMAMaterialApplications

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _AGMA_MATERIAL_APPLICATIONS

    __hash__ = None

    GENERAL_APPLICATION = 0
    CRITICAL_SERVICE = 1



'''_1082.py

InputSetter
'''


from typing import Generic, TypeVar

from mastapy._internal import constructor
from mastapy.math_utility.optimisation import _1088
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_INPUT_SETTER = python_net_import('SMT.MastaAPI.MathUtility.Optimisation', 'InputSetter')


__docformat__ = 'restructuredtext en'
__all__ = ('InputSetter',)


T = TypeVar('T')


class InputSetter(_1.APIBase, Generic[T]):
    '''InputSetter

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _INPUT_SETTER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'InputSetter.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def fix_this_property(self) -> 'bool':
        '''bool: 'FixThisProperty' is the original name of this property.'''

        return self.wrapped.FixThisProperty

    @fix_this_property.setter
    def fix_this_property(self, value: 'bool'):
        self.wrapped.FixThisProperty = bool(value) if value else False

    @property
    def last_path_object_name(self) -> 'str':
        '''str: 'LastPathObjectName' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LastPathObjectName

    @property
    def value(self) -> 'float':
        '''float: 'Value' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Value

    @property
    def optimiser_input(self) -> '_1088.ParetoOptimisationInput':
        '''ParetoOptimisationInput: 'OptimiserInput' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1088.ParetoOptimisationInput)(self.wrapped.OptimiserInput) if self.wrapped.OptimiserInput else None

    @property
    def candidate(self) -> 'T':
        '''T: 'Candidate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(T)(self.wrapped.Candidate) if self.wrapped.Candidate else None



'''_2785.py

RootAssemblySteadyStateSynchronousResponseAtASpeed
'''


from mastapy.system_model.part_model import _1993
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _2796, _2704
from mastapy._internal.python_net import python_net_import

_ROOT_ASSEMBLY_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed', 'RootAssemblySteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('RootAssemblySteadyStateSynchronousResponseAtASpeed',)


class RootAssemblySteadyStateSynchronousResponseAtASpeed(_2704.AssemblySteadyStateSynchronousResponseAtASpeed):
    '''RootAssemblySteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _ROOT_ASSEMBLY_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RootAssemblySteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_1993.RootAssembly':
        '''RootAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1993.RootAssembly)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def steady_state_synchronous_response_at_a_speed_inputs(self) -> '_2796.SteadyStateSynchronousResponseAtASpeed':
        '''SteadyStateSynchronousResponseAtASpeed: 'SteadyStateSynchronousResponseAtASpeedInputs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2796.SteadyStateSynchronousResponseAtASpeed)(self.wrapped.SteadyStateSynchronousResponseAtASpeedInputs) if self.wrapped.SteadyStateSynchronousResponseAtASpeedInputs else None



'''_3724.py

ConceptCouplingHalfModalAnalysesAtStiffnesses
'''


from mastapy.system_model.part_model.couplings import _2095
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6051
from mastapy.system_model.analyses_and_results.modal_analyses_at_stiffnesses_ns import _3735
from mastapy._internal.python_net import python_net_import

_CONCEPT_COUPLING_HALF_MODAL_ANALYSES_AT_STIFFNESSES = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtStiffnessesNS', 'ConceptCouplingHalfModalAnalysesAtStiffnesses')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptCouplingHalfModalAnalysesAtStiffnesses',)


class ConceptCouplingHalfModalAnalysesAtStiffnesses(_3735.CouplingHalfModalAnalysesAtStiffnesses):
    '''ConceptCouplingHalfModalAnalysesAtStiffnesses

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_COUPLING_HALF_MODAL_ANALYSES_AT_STIFFNESSES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptCouplingHalfModalAnalysesAtStiffnesses.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2095.ConceptCouplingHalf':
        '''ConceptCouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2095.ConceptCouplingHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6051.ConceptCouplingHalfLoadCase':
        '''ConceptCouplingHalfLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6051.ConceptCouplingHalfLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_672.py

GearNamePicker
'''


from mastapy._internal.implicit import list_with_selected_item
from mastapy._internal import constructor
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_GEAR_NAME_PICKER = python_net_import('SMT.MastaAPI.Gears.GearSetParetoOptimiser', 'GearNamePicker')


__docformat__ = 'restructuredtext en'
__all__ = ('GearNamePicker',)


class GearNamePicker(_1.APIBase):
    '''GearNamePicker

    This is a mastapy class.
    '''

    TYPE = _GEAR_NAME_PICKER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearNamePicker.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def names_detected_from_file(self) -> 'list_with_selected_item.ListWithSelectedItem_str':
        '''list_with_selected_item.ListWithSelectedItem_str: 'NamesDetectedFromFile' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_str)(self.wrapped.NamesDetectedFromFile) if self.wrapped.NamesDetectedFromFile else None

    @names_detected_from_file.setter
    def names_detected_from_file(self, value: 'list_with_selected_item.ListWithSelectedItem_str.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.TYPE
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else None)
        self.wrapped.NamesDetectedFromFile = value

    @property
    def gear(self) -> 'str':
        '''str: 'Gear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Gear



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3194 import AbstractAssemblyPowerFlow
    from ._3195 import AbstractShaftOrHousingPowerFlow
    from ._3196 import AGMAGleasonConicalGearMeshPowerFlow
    from ._3197 import AGMAGleasonConicalGearPowerFlow
    from ._3198 import AGMAGleasonConicalGearSetPowerFlow
    from ._3199 import AssemblyPowerFlow
    from ._3200 import BearingPowerFlow
    from ._3201 import BeltConnectionPowerFlow
    from ._3202 import BeltDrivePowerFlow
    from ._3203 import BevelDifferentialGearMeshPowerFlow
    from ._3204 import BevelDifferentialGearPowerFlow
    from ._3205 import BevelDifferentialGearSetPowerFlow
    from ._3206 import BevelDifferentialPlanetGearPowerFlow
    from ._3207 import BevelDifferentialSunGearPowerFlow
    from ._3208 import BevelGearMeshPowerFlow
    from ._3209 import BevelGearPowerFlow
    from ._3210 import BevelGearSetPowerFlow
    from ._3211 import BoltedJointPowerFlow
    from ._3212 import BoltPowerFlow
    from ._3213 import ClutchConnectionPowerFlow
    from ._3214 import ClutchHalfPowerFlow
    from ._3215 import ClutchPowerFlow
    from ._3216 import CoaxialConnectionPowerFlow
    from ._3217 import ComponentPowerFlow
    from ._3218 import ConceptCouplingConnectionPowerFlow
    from ._3219 import ConceptCouplingHalfPowerFlow
    from ._3220 import ConceptCouplingPowerFlow
    from ._3221 import ConceptGearMeshPowerFlow
    from ._3222 import ConceptGearPowerFlow
    from ._3223 import ConceptGearSetPowerFlow
    from ._3224 import ConicalGearMeshPowerFlow
    from ._3225 import ConicalGearPowerFlow
    from ._3226 import ConicalGearSetPowerFlow
    from ._3227 import ConnectionPowerFlow
    from ._3228 import ConnectorPowerFlow
    from ._3229 import CouplingConnectionPowerFlow
    from ._3230 import CouplingHalfPowerFlow
    from ._3231 import CouplingPowerFlow
    from ._3232 import CVTBeltConnectionPowerFlow
    from ._3233 import CVTPowerFlow
    from ._3234 import CVTPulleyPowerFlow
    from ._3235 import CylindricalGearGeometricEntityDrawStyle
    from ._3236 import CylindricalGearMeshPowerFlow
    from ._3237 import CylindricalGearPowerFlow
    from ._3238 import CylindricalGearSetPowerFlow
    from ._3239 import CylindricalPlanetGearPowerFlow
    from ._3240 import DatumPowerFlow
    from ._3241 import ExternalCADModelPowerFlow
    from ._3242 import FaceGearMeshPowerFlow
    from ._3243 import FaceGearPowerFlow
    from ._3244 import FaceGearSetPowerFlow
    from ._3245 import FlexiblePinAssemblyPowerFlow
    from ._3246 import GearMeshPowerFlow
    from ._3247 import GearPowerFlow
    from ._3248 import GearSetPowerFlow
    from ._3249 import GuideDxfModelPowerFlow
    from ._3250 import HypoidGearMeshPowerFlow
    from ._3251 import HypoidGearPowerFlow
    from ._3252 import HypoidGearSetPowerFlow
    from ._3253 import ImportedFEComponentPowerFlow
    from ._3254 import InterMountableComponentConnectionPowerFlow
    from ._3255 import KlingelnbergCycloPalloidConicalGearMeshPowerFlow
    from ._3256 import KlingelnbergCycloPalloidConicalGearPowerFlow
    from ._3257 import KlingelnbergCycloPalloidConicalGearSetPowerFlow
    from ._3258 import KlingelnbergCycloPalloidHypoidGearMeshPowerFlow
    from ._3259 import KlingelnbergCycloPalloidHypoidGearPowerFlow
    from ._3260 import KlingelnbergCycloPalloidHypoidGearSetPowerFlow
    from ._3261 import KlingelnbergCycloPalloidSpiralBevelGearMeshPowerFlow
    from ._3262 import KlingelnbergCycloPalloidSpiralBevelGearPowerFlow
    from ._3263 import KlingelnbergCycloPalloidSpiralBevelGearSetPowerFlow
    from ._3264 import MassDiscPowerFlow
    from ._3265 import MeasurementComponentPowerFlow
    from ._3266 import MountableComponentPowerFlow
    from ._3267 import OilSealPowerFlow
    from ._3268 import PartPowerFlow
    from ._3269 import PartToPartShearCouplingConnectionPowerFlow
    from ._3270 import PartToPartShearCouplingHalfPowerFlow
    from ._3271 import PartToPartShearCouplingPowerFlow
    from ._3272 import PlanetaryConnectionPowerFlow
    from ._3273 import PlanetaryGearSetPowerFlow
    from ._3274 import PlanetCarrierPowerFlow
    from ._3275 import PointLoadPowerFlow
    from ._3276 import PowerFlow
    from ._3277 import PowerFlowDrawStyle
    from ._3278 import PowerLoadPowerFlow
    from ._3279 import PulleyPowerFlow
    from ._3280 import RollingRingAssemblyPowerFlow
    from ._3281 import RollingRingConnectionPowerFlow
    from ._3282 import RollingRingPowerFlow
    from ._3283 import RootAssemblyPowerFlow
    from ._3284 import ShaftHubConnectionPowerFlow
    from ._3285 import ShaftPowerFlow
    from ._3286 import ShaftToMountableComponentConnectionPowerFlow
    from ._3287 import SpecialisedAssemblyPowerFlow
    from ._3288 import SpiralBevelGearMeshPowerFlow
    from ._3289 import SpiralBevelGearPowerFlow
    from ._3290 import SpiralBevelGearSetPowerFlow
    from ._3291 import SpringDamperConnectionPowerFlow
    from ._3292 import SpringDamperHalfPowerFlow
    from ._3293 import SpringDamperPowerFlow
    from ._3294 import StraightBevelDiffGearMeshPowerFlow
    from ._3295 import StraightBevelDiffGearPowerFlow
    from ._3296 import StraightBevelDiffGearSetPowerFlow
    from ._3297 import StraightBevelGearMeshPowerFlow
    from ._3298 import StraightBevelGearPowerFlow
    from ._3299 import StraightBevelGearSetPowerFlow
    from ._3300 import StraightBevelPlanetGearPowerFlow
    from ._3301 import StraightBevelSunGearPowerFlow
    from ._3302 import SynchroniserHalfPowerFlow
    from ._3303 import SynchroniserPartPowerFlow
    from ._3304 import SynchroniserPowerFlow
    from ._3305 import SynchroniserSleevePowerFlow
    from ._3306 import ToothPassingHarmonic
    from ._3307 import TorqueConverterConnectionPowerFlow
    from ._3308 import TorqueConverterPowerFlow
    from ._3309 import TorqueConverterPumpPowerFlow
    from ._3310 import TorqueConverterTurbinePowerFlow
    from ._3311 import UnbalancedMassPowerFlow
    from ._3312 import VirtualComponentPowerFlow
    from ._3313 import WormGearMeshPowerFlow
    from ._3314 import WormGearPowerFlow
    from ._3315 import WormGearSetPowerFlow
    from ._3316 import ZerolBevelGearMeshPowerFlow
    from ._3317 import ZerolBevelGearPowerFlow
    from ._3318 import ZerolBevelGearSetPowerFlow



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1011 import KeyedJointDesign
    from ._1012 import KeyTypes
    from ._1013 import KeywayJointHalfDesign
    from ._1014 import NumberOfKeys
